import { render, screen } from '@testing-library/react';
import Tile from './Tile';
import { TileKeyObject } from './types';

describe('The Tile component ', () => {
  const keyObject: TileKeyObject = {
    provider: 'fake',
    zoomLevel: 10,
    x: 1,
    y: 2,
  };
  test('Is initially empty', () => {
    const { baseElement } = render(
      <svg>
        <Tile keyObject={keyObject} delay={10000} />
      </svg>
    );
    //    screen.debug();
    expect(baseElement).toMatchInlineSnapshot(`
<body>
  <div>
    <svg>
      <g
        transform="translate(1, 2)"
      />
    </svg>
  </div>
</body>
`);
  });
  test('Gets its image immediately with a fake URL', () => {
    const { baseElement } = render(
      <svg>
        <Tile keyObject={keyObject} />
      </svg>
    );
    //    screen.debug();
    expect(baseElement).toMatchInlineSnapshot(`
<body>
  <div>
    <svg>
      <g
        transform="translate(1, 2)"
      >
        <image
          height="1"
          href="https://fakeurl/10/1/2.png"
          width="1"
        />
      </g>
    </svg>
  </div>
</body>
`);
  });
});
